Index: /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Utils.java
===================================================================
--- /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Utils.java	(revision 3594)
+++ /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Utils.java	(revision 3595)
@@ -26,5 +26,5 @@
 
 /**
- * Some static helper methods.
+ * Static helper methods for strings.
  * 
  * @version $Id$
@@ -102,6 +102,6 @@
 
 	/**
-	 * Checks if a string is whitespace, empty ("") or null. Whitespace is check
-	 * by {@link Character#isWhitespace(char)}.
+	 * Checks if a string is whitespace, empty ("") or null. Whitespace is
+	 * checked by {@link Character#isWhitespace(char)}.
 	 * 
 	 * @param str
Index: /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java
===================================================================
--- /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java	(revision 3594)
+++ /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java	(revision 3595)
@@ -30,5 +30,5 @@
 
 /**
- * Some static helper methods in conjunction with files.
+ * Static helper methods for files.
  * 
  * @version $Id$
@@ -94,11 +94,10 @@
 
 	/**
-	 * Checks whether a path complied the FCKeditor File Browser rules.<br/>
-	 * In particular a path has to comply with these <a href="http://docs.fckeditor.net/FCKeditor_2.x/Developers_Guide/Server_Side_Integration#File_Browser_Requests"
-	 * >rules</a>.
+	 * Checks whether a path complies with the FCKeditor File Browser <a href="http://docs.fckeditor.net/FCKeditor_2.x/Developers_Guide/Server_Side_Integration#File_Browser_Requests"
+	 * target="_blank">rules</a>.
 	 * 
 	 * @param path
 	 *            a potentially 'malicious' path
-	 * @return <code>true</code> if path complies to the rules, else
+	 * @return <code>true</code> if path complies with the rules, else
 	 *         <code>false</code>
 	 */
@@ -119,5 +118,5 @@
 
 	/**
-	 * Replaces all dots except the last one with underscores in a filename.
+	 * Replaces all dots in a filename with underscores except the last one.
 	 * 
 	 * @param filename
Index: /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java
===================================================================
--- /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java	(revision 3594)
+++ /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java	(revision 3595)
@@ -24,5 +24,5 @@
 
 /**
- * Some static helper methods in conjunction with the servlet response.
+ * Static helper methods for the servlet response.
  * 
  * @version $Id$
@@ -34,5 +34,4 @@
 	 * 
 	 * @see #fileUrl(String, ResourceType, String, String)
-	 * 
 	 */
 	public static String getUrl(String userFilesPath, ResourceType type,
Index: /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/XHtmlTagTool.java
===================================================================
--- /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/XHtmlTagTool.java	(revision 3594)
+++ /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/XHtmlTagTool.java	(revision 3595)
@@ -61,5 +61,5 @@
 	 * 
 	 * @param name
-	 *            the tag name of the new XHtmlTagTool
+	 *            the tag name of this new XHtmlTagTool
 	 * @throws IllegalArgumentException
 	 *             if <code>name</code> is empty
@@ -76,7 +76,7 @@
 	 * 
 	 * @param name
-	 *             the tag name of the new XHtmlTagTool
+	 *             the tag name of this new XHtmlTagTool
 	 * @param value
-	 *            the tag value of the new XHtmlTagTool which is the tag body
+	 *            the tag value of this new XHtmlTagTool which is the tag body
 	 * @throws IllegalArgumentException
 	 *             if <code>name</code> is empty
@@ -98,5 +98,5 @@
 
 	/**
-	 * Adds an attribute to the tag.
+	 * Adds an attribute to this tag.
 	 * 
 	 * @param name

Index: /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Compatibility.java
===================================================================
--- /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Compatibility.java	(revision 3594)
+++ /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Compatibility.java	(revision 3595)
@@ -26,6 +26,8 @@
 import javax.servlet.http.HttpServletRequest;
 
+import net.fckeditor.FCKeditor;
+
 /**
  * Checks browser compatibility with the editor.
  * 
  * @version $Id$
@@ -26,6 +26,8 @@
 /**
- * Checks browser compatibility with the editor.
+ * Checks browser compatibility with the {@link FCKeditor editor}.
  * 
  * @version $Id$